pub struct IpfsFetchPolicy { /* private fields */ }Expand description
Fetch policy for IPFS reads.
Implementations
Sourceimpl IpfsFetchPolicy
impl IpfsFetchPolicy
Sourcepub fn new(read_base_uri: impl Into<String>) -> Result<Self, AppDataError>
pub fn new(read_base_uri: impl Into<String>) -> Result<Self, AppDataError>
Creates a fetch policy with an explicit read base URI.
Errors
Returns AppDataError::Transport if the URI is empty after trimming.
Sourcepub fn from_config(config: &IpfsConfig) -> Result<Self, AppDataError>
pub fn from_config(config: &IpfsConfig) -> Result<Self, AppDataError>
Creates a fetch policy from IpfsConfig.
read_uri takes precedence over the general uri field.
Errors
Returns AppDataError::Transport if the resolved URI is empty after trimming.
Sourcepub fn read_base_uri(&self) -> &str
pub fn read_base_uri(&self) -> &str
Returns the normalized IPFS read base URI.
Sourcepub fn with_read_base_uri(
self,
read_base_uri: impl Into<String>,
) -> Result<Self, AppDataError>
pub fn with_read_base_uri( self, read_base_uri: impl Into<String>, ) -> Result<Self, AppDataError>
Returns a copy of this policy with a new read base URI.
Errors
Returns AppDataError::Transport if the URI is empty after trimming.